/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: AgentHeartbeat Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: AgentHeartbeat.inl,v 1.4 2007/01/31 16:26:43 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#include "glite/data/transfer/agent/dao/AgentDAO.h"
#include "log4cpp/Category.hh"

#include <boost/scoped_ptr.hpp>
#include <unistd.h>

/*
 * Constants
 */
namespace {
const char * const AGENT_HEARTBEAT_NAME  = "transfer-agent-heartbeat";
}

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
    
/*
 * AgentHeartbeat
 *
 * Constructor
 */
template <class F>
AgentHeartbeat<F>::AgentHeartbeat(): 
    m_logger(log4cpp::Category::getInstance(AGENT_HEARTBEAT_NAME)){
}
                                                                                                                          
/*
 * ~AgentHeartbeat
 *
 * Destructor
 */
template <class F>
AgentHeartbeat<F>::~AgentHeartbeat(){
}

/*
 * run
 *
 * Update the LastActive timestamp
 */
template <class F>
void AgentHeartbeat<F>::run(agents::dao::DAOContext& ctx, const std::string& name) /*throw(DAOException)*/{
    
    // Get current Time
    time_t current;
    time(&current);

    // Create DAO Context
    try{
        // Create a AgentDAO instance
        boost::scoped_ptr<dao::AgentDAO> agentDao(
            F::instance().createAgentDAO(name,ctx));
    
        // Try to get the Agent Instance
        boost::scoped_ptr<model::Agent> agent(agentDao->get());
        
        // Update Fields
        agent->state = model::Agent::S_STARTED;
        agent->lastActive = current;
        
        // Start Transaction
        ctx.start();
        
        // Insert the Instance
        agentDao->update(*agent);

        // Commit Transaction
        ctx.commit();

	// Also log the heartbeat (eventually a sensor could be easily created)
        m_logger.log(log4cpp::Priority::INFO,"HEARTBEAT: Agent <%s> is alive",name.c_str());
    } catch(const agents::dao::DAOException& exc){
        m_logger.log(log4cpp::Priority::ERROR,"Can't set Agent lastActive. Reason is %s",exc.what());
        ctx.rollback();
        throw;
    } catch(const agents::LogicError& exc){
        m_logger.log(log4cpp::Priority::ERROR,"Can't set Agent lastActive (LogicError). Reason is %s",exc.what());
        ctx.rollback();
        throw;
    }
}

} // end namespace agent
} // end namespace transfer
} // end namespace data
} // end namespace glite
