/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: VOConfig Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: AgentState.h,v 1.2 2006/08/14 08:37:38 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_AGENTSTATE_H_
#define GLITE_DATA_TRANSFER_AGENTS_AGENTSTATE_H_

#include "glite/data/transfer/agent/model/Agent.h"
#include "glite/data/agents/dao/DAOContext.h"

#include <boost/utility.hpp>
#include <string>

namespace log4cpp{
    class Category;
}

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {

/**
 * The AgentState Class
 */   
template <class F>
class AgentState : boost::noncopyable {
public:
    
    /**
     * Constructor
     */
    AgentState(class agents::dao::DAOContext& ctx,
               const std::string& n,
               const std::string& t,
               const std::string& c = "",
               unsigned int heartbeat_interval = 60);
                                                                                                                           
    /**
     * Destructor
     */
    ~AgentState();

    /**
     * Set Agent State
     */
    void set(model::Agent::State s) /*throw (DAOException,LogicError)*/;

    /**
     * Check if an Agent is still running
     */
    bool check() /*throw (DAOException,LogicError)*/;

    /**
     * Update Agent State
     */
    void update(model::Agent::State s) /*throw(DAOException,LogicError)*/;
      
private:
    
    /**
     * Default Constructor. Not Implemented
     */
    AgentState();

private:
    /**
     * The Logger
     */
    class log4cpp::Category& m_logger;
                    
    /**
     * The DAO Context
     */
    class agents::dao::DAOContext& m_ctx;
        
    /**
     * The VO/Channel Name of the Agent
     */
    std::string  m_name;

    /**
     * The Type of the Agent
     */
    std::string  m_type;

    /**
     * The Name of the Contact for that Agent
     */
    std::string  m_contact;
    
    /**
     * The heartbeat Interval: specify the interval used to update the Agent 
     * lastActive time
     */
    unsigned int m_heartbeatInterval;
};

} // end namespace agent
} // end namespace transfer
} // end namespace data
} // end namespace glite

#include "glite/data/transfer/agent/AgentState.inl"

#endif //GLITE_DATA_TRANSFER_AGENTS_AGENTSTATE_H_
