/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: Action Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: Action.h,v 1.4 2006/08/14 08:37:40 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_ACTION_ACTION_H_
#define GLITE_DATA_TRANSFER_AGENTS_ACTION_ACTION_H_

#include "glite/data/transfer/agent/action/ExecuteException.h"

#include <boost/utility.hpp>

namespace glite   {
namespace data    {
    
/*
 * Forward Declaration
 */   
namespace agents  {
namespace dao     {
class DAOContext;
}
}

namespace transfer{
namespace agent   {
namespace action  {
    
/**
 * Action Interface
 * @interface
 */
class Action : boost::noncopyable{
public:

    /**
     * Destructor
     */
    virtual ~Action(){}
       
    /**    
     * set DAOContext
     */
    virtual void context(const std::string& params, class glite::data::agents::dao::DAOContext& ctx) /*throw (LogicError, ExecuteException)*/ = 0;
    
    /**    
     * Get DAOContext
     */
    virtual class glite::data::agents::dao::DAOContext& context() /*throw (LogicError)*/ = 0;
            
    /**
     * Execute The Action
     */
    virtual void execute(const std::string& params = "") /*throw (LogicError, ExecuteException)*/ = 0;
private:

    /** @link dependency 
     * @label throws*/
    /*# ExecuteException lnkExecuteException; */
};

} // End namespace action
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_ACTION_ACTION_H_
