/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: ActionFactory Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: ActionFactory.h,v 1.3 2006/08/14 08:37:40 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_ACTION_ACTIONFACTORY_H_
#define GLITE_DATA_TRANSFER_AGENTS_ACTION_ACTIONFACTORY_H_

#include "glite/data/transfer/agent/action/ExecuteException.h"
#include "glite/data/transfer/agent/action/Action.h"
#include <map>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace action  {

/*
 * Forward Declaration
 */  
class ActionFactoryMethod;
    
/**
 * ActionFactory Class
 */
class ActionFactory {
public:
    
    /**
     * Returns singleton instance
     * @return singleton instance
     */
    static ActionFactory& instance();

    /**
     * Create an instance of an action of the given type
     * @param type [IN] the type of the Action to create
     * @return the created instance
     * @throws LogicError in case of the Action type is not configured
     */
    Action * create(const std::string& type) /*throw (LogicError)*/;

    /**
     * Get the action factory method for a gven type
     * @param type [IN] the type of the Action to create
     * @return the factory method instance responsible to create action of 
     * the given type
     * @throws LogicError in case of the Action type is not configured
     */
    ActionFactoryMethod& get(const std::string& type) /*throw (LogicError)*/;

    /**
     * Register a Factory Method and Acquir its ownership
     * @param type [IN] the type of the Action the factory is able to create
     * @param factory [IN] the Action the factory instance
     * @throws LogicError in case of the Action type is already registered
     */
    void registerMethod(const std::string& type, ActionFactoryMethod * factory) /*throw (LogicError)*/;

private:
    
    /**
     * Constructor
     */
    ActionFactory();

    /**
     * Destructor
     */
    ~ActionFactory();

private:

    /**
     * The Action Factory Method Map Type
     */
    typedef std::map<std::string, ActionFactoryMethod *> FactoryMap;

    /**
     * The Action Factory Method Map
     */
    FactoryMap m_actionFactoryMap;

    /** @link dependency 
     * @label creates*/
    /*# Action lnkAction; */
};

} // End namespace action
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_ACTION_ACTIONFACTORY_H_
