/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: BasicRetry Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: Retry.h,v 1.2 2006/08/14 08:37:41 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_ACTION_VO_RETRY_H_
#define GLITE_DATA_TRANSFER_AGENTS_ACTION_VO_RETRY_H_

#include "glite/data/transfer/agent/action/vo/VOAction.h"
#include "glite/data/transfer/agent/action/vo/RetryStrategy.h"
#include "glite/data/transfer/agent/action/vo/CatalogRetryStrategy.h"

#include <string>
#include <vector>
#include <boost/scoped_ptr.hpp>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace action  {
namespace vo      {

/**
 * The purpose of that Action is to trigger the event to reschedule transfers
 * in Waiting State
 */
class Retry : public VOAction {
public:
    /**
     * Destructor
     */
    virtual ~Retry();

    /**
     * Execute The Action. Overrid ethe default since the transaction are 
     * executed per Job
     */
    virtual void execute(const std::string& params = "") /*throw (LogicError,ExecuteException)*/;

protected:
    typedef std::vector<std::string> StringArray;

    /**
     * Constructor
     */
    Retry(const std::string& name, RetryStrategy * s, CatalogRetryStrategy * cs);

    /**
     * Execute The Action
     */
    virtual void exec(const std::string& params) /*throw (DAOException,LogicError,ExecureException)*/;

private:
    
    /**
     * Execute Retry Strategy for Transfer that failed
     */
    void retryTransferFailed() /*throw (DAOException,LogicError,ExecuteException)*/;

    /**
     * Execute Retry Strategy for File that failed during Catalog Interaction
     */
    void retryCatalogFailed() /*throw (DAOException,LogicError,ExecuteException)*/;

    /**
     * Execute Retry Strategy for File that failed during Prestaging
     */
    void retryPrestageFailed() /*throw (DAOException,LogicError,ExecuteException)*/;
     
    /**
     * Trigger the rescheduling on a file
     */
    void processFile(const std::string& file_id) /*throw (DAOException,LogicError)*/;

    /**
     * process a job with CatalogFailed files
     */
    void processCatalogFailedJob(const std::string& job_id, const StringArray& file_ids) /*throw (DAOException,LogicError)*/;

private:
    /**
     * Constructor. Not Implemented
     */
    Retry();

private:
    /**
     * The Retry Strategy to use
     */
    boost::scoped_ptr<RetryStrategy> m_strategy;
    /**
     * The Catalog Retry Strategy to use
     */
    boost::scoped_ptr<CatalogRetryStrategy> m_catalogStrategy;
};

} // End namespace vo
} // End namespace action
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_ACTION_VO_RETRY_H_
