/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: CatalogServiceException Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: CatalogServiceException.h,v 1.4 2006/08/14 08:37:42 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_CATALOG_CATALOGSERVICEEXCEPTION_H_
#define GLITE_DATA_TRANSFER_AGENTS_CATALOG_CATALOGSERVICEEXCEPTION_H_

#include "glite/data/agents/AgentExceptions.h"
#include <string>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace catalog {
    
/**
 * The Exception is thrown when an Logical error happens on CatalogService
 */
class CatalogLogicError : public glite::data::agents::LogicError {
public:

    /**
     * Constructor
     * @param reason [IN] the reason of the error
     */
    CatalogLogicError(const std::string& reason):glite::data::agents::LogicError(reason){}

    /**
     * Destructor
     */
    virtual ~CatalogLogicError() throw() {}
    
private:

    /**
     * Default Constructor Not Implemented
     */
    CatalogLogicError();
};

/**
 * The Exception is thrown when an error happens on contacting the CatalogService
 */
class CatalogRemoteError : public glite::data::agents::RuntimeError {
public:

    /**
     * Constructor
     * @param reason [IN] the reason of the error
     */
    CatalogRemoteError(const std::string& reason):glite::data::agents::RuntimeError(reason){}

    /**
     * Destructor
     */
    virtual ~CatalogRemoteError() throw() {}
    
private:

    /**
     * Default Constructor Not Implemented
     */
    CatalogRemoteError();
};

} // end namespace catalog
} // end namespace agent
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_CATALOG_CATALOGSERVICEEXCEPTION_H_
