/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: ChannelDAO Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: ChannelDAO.h,v 1.7 2007/03/21 14:15:50 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNELDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNELDAO_H_

#include "glite/data/transfer/agent/model/Channel.h"
#include "glite/data/agents/dao/DAOException.h"
#include "glite/data/agents/dao/dao-types.h"

#include <string>
#include <boost/utility.hpp>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {

/**
 * Data Access Object For the model::Channel class
 * @interface
 */
class ChannelDAO : boost::noncopyable{
public:

    /**
     * Destructor
     */
    virtual ~ChannelDAO(){}
        
    /**
     * Return the Channel with the given Name
     */
    virtual model::Channel * get(const std::string& name) /*throw (DAOLogicError,DAOException)*/ = 0;
          
    /**
     * Return the list of groups which a site belong to
     */
    virtual void getSiteGroups(const std::string& site, agents::dao::StringArray& groups) /*throw (DAOLogicError,DAOException)*/ = 0;
   
private:

    /** @link dependency 
     * @label creates/updates*/
    /*# model::Channel lnkChannel; */

    /** @link dependency 
     * @label throws*/
    /*# DAOException lnkDAOException; */
};

} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite


#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNELDAO_H_
