/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: FileDAO Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: FileDAO.h,v 1.6 2006/08/14 08:37:44 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_FILEDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_FILEDAO_H_

#include "glite/data/transfer/agent/model/File.h"
#include "glite/data/agents/dao/DAOException.h"
#include "glite/data/agents/dao/dao-types.h"

#include <string>
#include <boost/utility.hpp>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {

/**
 * Data Access Object For the model::File class
 * @interface
 */
class FileDAO : boost::noncopyable {
public:
    /**
     * Destructor
     */
    virtual ~FileDAO(){}

    /**
     * Return the File with the given Id
     */
    virtual model::File * get(const std::string& id) /*throw (DAOLogicError,DAOException)*/ = 0;

    /**
     * Update a File instance
     */
    virtual void update(const model::File& obj) /*throw (DAOLogicError,DAOException)*/ = 0;

    /**
     * Return the list of File instances for the given job Id
     */
    virtual void getByJobId(const std::string& job_id, agents::dao::StringArray& ids) /*throw (DAOException)*/ = 0;

private:

    /** @link dependency 
     * @label creates/updates*/
    /*# glite::data::transfer::agent::model::File lnkFile; */
};

} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_FILEDAO_H_
