/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: JobDAO Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: JobDAO.h,v 1.9 2006/08/14 08:37:45 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_JOBDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_JOBDAO_H_

#include "glite/data/transfer/agent/model/Job.h"
#include "glite/data/agents/dao/DAOException.h"
#include "glite/data/agents/dao/dao-types.h"

#include <string>
#include <boost/utility.hpp>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {

/**
 * Data Access Object For the model::Job class
 * @interface
 */
class JobDAO : boost::noncopyable{
public:

    /**
     * Destructor
     */
    virtual ~JobDAO(){}
        
    /**
     * Return the Job with the given id
     */
    virtual model::Job * get(const std::string& id) /*throw (DAOLogicError,DAOException)*/ = 0;

    /**
     * Update a Job object
     */
    virtual void update(const model::Job& obj) /*throw (DAOLogicError,DAOException)*/ = 0;

    /**
     * Update the state of all the transfer jobs in the given array
     * Note: Probably this shoudn't be a DAO method, but I assume that it could 
     * be implemented using features like Triggers or Stored Procedures 
     * available on some Data Sources
     */
    virtual void updateStates(const agents::dao::StringArray& ids) /*throw (DAOException)*/ = 0;

private:

    /** @link dependency 
     * @label creates/updates*/
    /*# glite::data::transfer::agent::model::Job lnkJob; */
};

} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite


#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_JOBDAO_H_
