/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: TSSCredFactory
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: TSSCredFactory.h,v 1.2 2006/08/14 08:37:45 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_TSSCREDFACTORY_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_TSSCREDFACTORY_H_

#include "glite/data/agents/dao/DAOContext.h"
#include "glite/data/transfer/agent/dao/CredDAO.h"
#include "glite/data/agents/extra/TSS.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {
    
/**
 * The purpose of this class is to create a CredDao with the 
 * correct Factory(vo,channel,cred)
 */
class CredFactory : boost::noncopyable{
public:

    /**
     * create a CredDao with the correct Factory
     */
    virtual CredDAO * create(agents::dao::DAOContext& ctx) /*throw (DAOLogicError)*/ = 0;

    /**
     * Destructor
     */
    virtual ~CredFactory(){};
protected:
    /**
     * Constructor
     */
    CredFactory(){};
};
    
// -----------------------------------------------------------------------------
// -----------------------------------------------------------------------------
// Declare the TSS for the Cred Factory (so the correct factory is always used 
// within a thread)
// -----------------------------------------------------------------------------
// -----------------------------------------------------------------------------
extern agents::TSS<CredFactory> g_tss_cred_factory;
    
} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_TSSCREDFACTORY_H_
