/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: FileDAO Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: FileDAO.h,v 1.7 2007/03/12 15:03:19 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_FILEDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_FILEDAO_H_

#include "glite/data/transfer/agent/model/File.h"
#include "glite/data/transfer/agent/dao/FileDAO.h"
#include "glite/data/transfer/agent/dao/StringArrayTable.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {
namespace channel {

/**
 * Data Access Object For the model::File class filtered with a Channel View
 * @interface
 */
class FileDAO : public glite::data::transfer::agent::dao::FileDAO {
public:

    /**
     * Destructor
     */
    virtual ~FileDAO(){}

    /**
     * Return the next job (and file) Ids to transfer for the given 
     * channel following the rule: files in ready state, which job 
     * state is ready or active, not in canceling, order by job_priority, 
     * job submission time, job_id for the given VO
     */
    virtual void getNextJobToTransfer(const std::string& vo_name, std::string& job_id, agents::dao::StringArray& file_ids, unsigned int limit = 0) /*throw (DAOException,DAOLogicError)*/ = 0;

    /**
     * Return the next jobs' and files' ids, groups by SEs' pair, to transfer 
     * for the given 
     * channel following the rule: files in pending or waiting state, which job 
     * state is pending, order by job_priority, job submission time, job_id for 
     * the given VO
     */
    virtual void getJobsToTransferPerSE(const std::string& vo_name, dao::StringArrayTable& ids, unsigned int se_limit, unsigned int limit = 0) /*throw (DAOLogicError, DAOException)*/ = 0;
        
    /**
     * Return the job and file Ids to cancel for the given 
     * channel following the rule: files in Ready, Done or Hold state, which job 
     * state is ready or active, with canceljob flag set to true, order by 
     * job_priority, job submission time, job id 
     */
    virtual void getFilesToCancel(StringArrayTable& ids, unsigned int limit = 0) /*throw (DAOException,DAOLogicError)*/ = 0;
};

} // End namespace channel
} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_CHANNEL_FILEDAO_H_
