/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: CredDAO Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: CredDAO.h,v 1.2 2006/08/14 08:37:47 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_CRED_CREDDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_CRED_CREDDAO_H_

#include "glite/data/transfer/agent/dao/CredDAO.h"

#include "glite/data/agents/dao/dao-types.h"

#include <string>
#include <boost/utility.hpp>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {
namespace cred    {

/**
 * Data Access Object For the model::Cred class
 * @interface
 */
class CredDAO : public glite::data::transfer::agent::dao::CredDAO {
public:

    typedef  agents::dao::StringPair      StringPair;
    typedef  agents::dao::StringPairArray StringPairArray;
    
    /**
     * Destructor
     */
    virtual ~CredDAO(){}
        
    /**
     * Return the Cred with the given Name
     */
    virtual model::Cred * get(const std::string& id, const std::string& user_dn) /*throw (DAOLogicError, DAOException)*/ = 0;

    /**
     * Update the Cred instance
     */
    virtual void update(model::Cred& cred) /*throw (DAOLogicError, DAOException)*/ = 0;

    /**
     * Get the identifiers of the Credentials that are going to expire and 
     * have Pending or Active jobs
     */
    virtual void getExpiringCreds(StringPairArray& ids, unsigned int validity, unsigned int limit = 0) /*throw (DAOLogicError, DAOException)*/ = 0;

private:

    /** @link dependency 
     * @label creates/updates*/
    /*# model::Cred lnkCred; */
};

} // End namespace cred
} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite


#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_CRED_CREDDAO_H_
