/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: JobDAO Class, Cred View
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: JobDAO.h,v 1.2 2006/08/14 08:37:47 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_CRED_JOBDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_CRED_JOBDAO_H_

#include "glite/data/transfer/agent/model/Job.h"
#include "glite/data/agents/dao/DAOException.h"
#include "glite/data/agents/dao/dao-types.h"

#include <string>
#include <boost/utility.hpp>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {
namespace cred    {

/**
 * Data Access Object For the model::Job class, Cred View. This interface doesn't 
 * inherit from the base JobDao Interface since the methods will be completely 
 * different
 * @interface
 */
class JobDAO : boost::noncopyable{
public:

    /**
     * Destructor
     */
    virtual ~JobDAO(){}
        
    /**
     * Return the Last Job submitted by the given user with the given credential id
     */
    virtual model::Job * getLast(const std::string& cred_id, const std::string& user_dn) /*throw (DAOLogicError,DAOException)*/ = 0;

private:

    /** @link dependency 
     * @label creates/updates*/
    /*# glite::data::transfer::agent::model::Job lnkJob; */
};

} // End namespace cred
} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite


#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_JOBDAO_H_
