/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: TSSCredFactory
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: CredVOFactory.h,v 1.2 2006/08/14 08:37:48 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_VO_CREDVOFACTORY_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_VO_CREDVOFACTORY_H_

#include "glite/data/transfer/agent/dao/TSSCredFactory.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {
namespace vo      {
    
/**
 * The purpose of this class is to create a CredDao with the 
 * correct Factory(vo,channel,cred)
 */
class CredVOFactory: public CredFactory {
public:
    /**
     * Constructor
     */
    explicit CredVOFactory(const std::string& vo_name):m_voName(vo_name){};

    /**
     * create a CredDao with the correct Factory
     */
    virtual CredDAO * create(agents::dao::DAOContext& ctx) /*throw (DAOLogicError)*/{
        // Create a CredDAO from the VO DAOFactory
        return dao::vo::DAOFactory::instance().createCredDAO(m_voName,ctx);
    }

    /**
     * Destructor
     */
    virtual ~CredVOFactory(){};
private:
    /**
     * Constructor. Not Implemented
     */
    CredVOFactory();
private:
    /**
     * The VO Name
     */
    std::string m_voName;
};
    
} // End namespace vo
} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_VO_CREDVOFACTORY_H_
