/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: VOViewDAOFactory Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: DAOFactory.h,v 1.5 2006/08/14 08:37:48 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_VO_DAOFACTORY_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_VO_DAOFACTORY_H_

#include "glite/data/agents/dao/DAOContext.h"
#include "glite/data/transfer/agent/dao/vo/FileDAO.h"
#include "glite/data/transfer/agent/dao/vo/JobDAO.h"
#include "glite/data/transfer/agent/dao/vo/TransferDAO.h"
#include "glite/data/transfer/agent/dao/vo/StageReqDAO.h"
#include "glite/data/transfer/agent/dao/vo/ChannelDAO.h"
#include "glite/data/transfer/agent/dao/vo/AgentDAO.h"
#include "glite/data/transfer/agent/dao/vo/CredDAO.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {
namespace vo      {

/**
 * Base Class For creating the DataAccessObject VOView instances
 * @interface
 */
class DAOFactory {
public:
    
    /**
     * Validate The DB Schema
     * @param ctx [IN] The DAO Context to use
      */
    virtual void checkSchema(agents::dao::DAOContext& ctx) /*throw (DAOLogicError, DAOException)*/ = 0;

    /**
     * Returns DataAccessObject for model:File instances
     * @param vo_name [IN] The name of the VO to view on
     * @param ctx [IN] The DAO Context to use
     */
    virtual FileDAO * createFileDAO(const std::string& vo_name, agents::dao::DAOContext& ctx) /*throw (DAOLogicError)*/ = 0;

    /**
     * Returns DataAccessObject for model:Job instances
     * @param vo_name [IN] The name of the VO to view on
     * @param ctx [IN] The DAO Context to use
     */
    virtual JobDAO * createJobDAO(const std::string& vo_name, agents::dao::DAOContext& ctx) /*throw (DAOLogicError)*/ = 0;

    /**
     * Returns DataAccessObject for model:Transfer instances
     * @param vo_name [IN] The name of the VO to view on
     * @param ctx [IN] The DAO Context to use
     */
    virtual TransferDAO * createTransferDAO(const std::string& vo_name, agents::dao::DAOContext& ctx) /*throw (DAOLogicError)*/ = 0;

    /**
     * Returns DataAccessObject for model:StageReq instances
     * @param vo_name [IN] The name of the VO to view on
     * @param ctx [IN] The DAO Context to use
     */
    virtual StageReqDAO * createStageReqDAO(const std::string& vo_name, agents::dao::DAOContext& ctx) /*throw (DAOLogicError)*/ = 0;

    /**
     * Returns DataAccessObject for model:Channel instances
     * @param vo_name [IN] The name of the VO to view on
     * @param ctx [IN] The DAO Context to use
     */
    virtual ChannelDAO * createChannelDAO(const std::string& vo_name, agents::dao::DAOContext& ctx) /*throw (DAOLogicError)*/ = 0;

    /**
     * Returns DataAccessObject for model:Agent instances
     * @param vo_name [IN] The name of the VO to view on
     * @param ctx [IN] The DAO Context to use
     */
    virtual AgentDAO * createAgentDAO(const std::string& vo_name, agents::dao::DAOContext& ctx) /*throw (DAOLogicError)*/ = 0;

    /**
     * Returns DataAccessObject for model::Cred instances
     * @param vo_name [IN] The name of the VO to view on
     * @param ctx [IN] The DAO Context to use
     */
    virtual CredDAO * createCredDAO(const std::string& vo_name, agents::dao::DAOContext& ctx) /*throw (DAOLogicError)*/ = 0;

    /**
     * Return the configured DAOFactory Instance. Please note that 
     * this method doesn't allocate the instance (Isn not a singleton)
     * @return the configured DAOFactory 
     * @throws DAOLogicError in case of no DAOFactory is configured
     */
    static DAOFactory& instance() /*throw (DAOLogicError)*/;

protected:

    /**
     * Constructor
     */ 
    DAOFactory();

    /**
     * Destructor
     */ 
    virtual ~DAOFactory();

private:

    /**
     * The registered Instance
     */
    static DAOFactory * s_instance;
    
    /** @link dependency 
     * @label creates*/
    /*# FileDAO lnkFileDAO; */

    /** @link dependency 
     * @label creates*/
    /*# JobDAO lnkJobDAO; */

    /** @link dependency
     * @label creates*/
    /*# TransferDAO lnkTransferDAO; */

    /** @link dependency 
     * @label creates*/
    /*# ChannelDAO lnkChannelDAO; */
};

} // End namespace vo
} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_VO_DAOFACTORY_H_
