/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: VOViewJobDAO Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: JobDAO.h,v 1.6 2006/08/14 08:37:48 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_DAO_VO_JOBDAO_H_
#define GLITE_DATA_TRANSFER_AGENTS_DAO_VO_JOBDAO_H_

#include "glite/data/transfer/agent/model/Job.h"
#include "glite/data/transfer/agent/dao/JobDAO.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace dao     {
namespace vo      {

/**
 * Data Access Object For the model::Job class
 * @interface
 */
class JobDAO : public glite::data::transfer::agent::dao::JobDAO {
public:

    /**
     * Destructor
     */
    virtual ~JobDAO(){}
         
    /**
     * Return the list of Submitted Job identifiers that have File sin Submitted State.
     */
    virtual void getSubmittedJobs(agents::dao::StringArray& jobIds, unsigned int limit = 0) /*throw (DAOLogicError, DAOException)*/ = 0;

    /**
     * Return the list of Job identifiers that are in Pending or Active state 
     * with at least one file in Pending state or that hould be canceled and have
     * at least on file in Hold state
     */
    virtual void getPendingJobs(agents::dao::StringArray& jobIds, unsigned int limit = 0) /*throw (DAOLogicError, DAOException)*/ = 0;

    /**
     * Return the list of Job identifiers that are in Done or DoneWithErrors state
     */
    virtual void getDoneJobs(agents::dao::StringArray& jobIds, unsigned int limit = 0) /*throw (DAOLogicError, DAOException)*/ = 0;

    /**
     * Return the list of Job identifiers that are in Finishing state
     */
    virtual void getFinishingJobs(agents::dao::StringArray& jobIds, unsigned int limit = 0) /*throw (DAOLogicError, DAOException)*/ = 0;
};

} // End namespace vo
} // End namespace dao
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite


#endif //GLITE_DATA_TRANSFER_AGENTS_DAO_VO_JOBDAO_H_
