/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: JobEventListener interface
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: JobEventListener.h,v 1.2 2006/08/14 08:37:49 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_FSM_JOBEVENTLISTENER_H_
#define GLITE_DATA_TRANSFER_AGENTS_FSM_JOBEVENTLISTENER_H_

#include "glite/data/transfer/agent/model/Job.h"

#include <boost/utility.hpp>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace fsm     {

/**
 * JobEventListener Interface
 * @interface
 */
class JobEventListener : boost::noncopyable {
public:
        
    // -------------------------------------------------------------------------
    // -------------------------------------------------------------------------
    // Generic Event Handler
    // -------------------------------------------------------------------------
    // -------------------------------------------------------------------------

    /**
     * This method is used to notify a job state transition. This method 
     * should not throw any exceptions
     * @param job [IN] the job instance which state is changed
     * @param old_state [IN] the previous job's state
     */
    virtual void onStateChanged(const model::Job& job, model::Job::State old_state) throw(){}
        

    // -------------------------------------------------------------------------
    // -------------------------------------------------------------------------
    // Specific Event Handlers: Listeners may be interested in just relevant 
    // events; these specific event handlers are provided in orer to avoid
    // the listener implementations to filter the generic events.
    // Please note that the generic event handler is called in any case
    // -------------------------------------------------------------------------
    // -------------------------------------------------------------------------

    /**
     * This method is used to notify that a job is Pending, i.e. accepted by 
     * the VO Agent
     * @param job [IN] the job instance which state is changed
     */
    virtual void onPending(const model::Job& job) throw(){};

    /**
     * This method is used to notify that a job is Finished or FinishedDirty
     * @param job [IN] the job instance which state is changed
     */
    virtual void onFinished(const model::Job& job) throw(){};

protected:
    /**
     * Constructor
     */
    JobEventListener();

    /**
     * Destructor
     */
    virtual ~JobEventListener();
};

} // End namespace fsm
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_FSM_JOBEVENTLISTENER_H_
