/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: Cred Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: Cred.h,v 1.2 2006/08/14 08:37:49 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_MODEL_CRED_H_
#define GLITE_DATA_TRANSFER_AGENTS_MODEL_CRED_H_

#include "glite/data/transfer/agent/model/Property.h"
#include <string>
#include <vector>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace model   {

/**
 * Cred Class
 * @stereotype ValueObject
 */
struct Cred {

    /**
     * Default Constructor
     */
    Cred():expirationTime(-1){}

    /**
     * Constructor
     */
    Cred(const std::string& i,              // cred_id
         const std::string& dn,             // user_dn
         const std::string& c  = "",        // certificate
               time_t       t  = (time_t)-1,// expiration_time
         const std::string& va = ""):       // voms_attribute
            id(i),userDn(dn),certificate(c),expirationTime(t),
            vomsAttributes(va){}
    /**
     * Id Property
     */
    Property<std::string> const id;

    /**
     * User DN Property
     */
    Property<std::string> const userDn;

    /**
     * User Proxy Property
     */
    Property<std::string> certificate;

    /**
     * Proxy Expiration Time Property
     */
    Property<time_t> expirationTime;

    /**
     * VOMS Attributes Property
     */
    Property<std::string> const vomsAttributes;

public:
    /**
     * Reset All R/W Properties
     */
    void reset(){
        certificate.reset();
        expirationTime.reset();
    }        
};

} // End namespace model
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_MODEL_CRED_H_
