/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: Error Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: Error.h,v 1.2 2006/08/14 08:37:49 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_MODEL_ERROR_H_
#define GLITE_DATA_TRANSFER_AGENTS_MODEL_ERROR_H_

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace model   {
    
/**
 * Error
 */
class Error{
public:

    /**
     * Error Category Type
     */
    typedef enum {
        UNDEF             =  0,
        TRANSFER          =  1, // Transfer Error
        AGENT             =  2, // Generic Agent Error
        SECURITY          =  3, // Security Error
        SOURCE            =  4, // Generic problem with the Source SE
        SOURCE_PREP       =  5, // Problem with the file preparation on the Source SE
        SOURCE_FINAL      =  6, // Problem with the file finalization on the Source SE
        DESTINATION       =  7, // Generic problem with the Destination SE
        DESTINATION_PREP  =  8, // Problem with the file preparation on the Destination SE
        DESTINATION_FINAL =  9, // Problem with the file finalization on the Destination SE
        NETWORK           = 10, // Network problem
        CONFIGURATION     = 11, // Configuration Problem
        CONSISTENCY       = 12, // Consistency Problem
        REMOTE            = 13, // Generic problem in contacting a remote server
        CATALOG           = 14, // Generic Catalog Error
        CATALOG_SRC       = 15, // Generic Catalog problem for the source file
        CATALOG_SRC_RES   = 16, // Problem during Source Name Resolution
        CATALOG_DST       = 17, // Generic Catalog problem for the destination file
        CATALOG_DST_RES   = 18, // Problem during Destination Name Resolution
        CATALOG_DST_REG   = 19  // Problem during Registration to the Destination Catalog
    } Category;
    
protected:
    /**
     * Constructor. Not Implemented
     */
    Error();
    /**
     * Destructor. Not Implemented
     */
    ~Error();
};

} // end namespace model
} // end namespace agent
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_MODEL_ERROR_H_
