/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: StageRequest Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: StageReq.h,v 1.2 2006/08/14 08:37:50 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_MODEL_STAGEREQ_H_
#define GLITE_DATA_TRANSFER_AGENTS_MODEL_STAGEREQ_H_

#include <string>
#include "glite/data/agents/glite-types.h"
#include "glite/data/transfer/agent/model/Error.h"
#include "glite/data/transfer/agent/model/Property.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace model   {
    
/**
 * StageReq Class
 * @stereotype ValueObject
 */
struct StageReq {

    typedef enum{ // Define values so they could combined in OR
        S_UNDEF           = 0x0000,
        S_SUBMITTED       = 0x0001,
        S_PROCESSING      = S_SUBMITTED    << 1,  //0x0002
        S_STAGED          = S_PROCESSING   << 1,  //0x0004
        S_FINALIZING      = S_STAGED       << 1,  //0x0008
        S_COMPLETED       = S_FINALIZING   << 1,  //0x0010
        S_FAILED          = S_COMPLETED    << 1,  //0x0020
        S_ABORTED         = S_FAILED       << 1   //0x0040
    } State;

    /**
     * Default Constructor
     */
    StageReq():stageId(0),
               state(S_UNDEF),
               requestTime((time_t)-1),duration(0.0),finalDuration(0.0),
               reasonClass(Error::UNDEF),fileSize(0){}
                     
    /**
     * Constructor
     */
    StageReq(const std::string&     req_id,             // request_id
             const std::string&     file_id,            // file_id
                   unsigned int     s_id,               // stage_id
             const std::string&     j_id,               // job_id
                   State            s,                  // state
             const std::string&     tu  = "",           // turl
                   time_t           t   = (time_t)-1,   // request_time
                   double           d   = 0.0,          // duration
                   double           f_d = 0.0,          // finalization_duration
                   Error::Category  rc  = Error::UNDEF, // reason_class
             const std::string&     r   = "",           // reason
                   agents::longlong fs  = 0):           // file_size
                 requestId(req_id),fileId(file_id),stageId(s_id),jobId(j_id),
                 state(s),turl(tu),requestTime(t),duration(d),finalDuration(f_d),
                 reasonClass(rc),reason(r),fileSize(fs){}

    /**
     * RequestId Property
     */
    Property<std::string> const requestId;

    /**
     * FileId Property
     */
    Property<std::string> const fileId;

    /**
     * StageId Property
     */
    Property<unsigned int> const stageId;

    /**
     * JobId Property
     */
    Property<std::string> const jobId;

    /**
     * State Property
     */
    Property<State> state;

    /**
     * TURL Property
     */
    Property<std::string> turl;

    /**
     * Stage Request Time Property
     */
    Property<time_t> requestTime;

    /**
     * Stage Duration Property
     */
    Property<double> duration;

    /**
     * Stage Finalization Duration Property
     */
    Property<double> finalDuration;

    /**
     * ReasonClass Property
     */
    Property<Error::Category> reasonClass;

    /**
     * Reason Property
     */
    Property<std::string> reason;

    /**
     * File Size Property
     */
    Property<agents::longlong> fileSize;

public:
    /**
     * Reset All R/W Properties
     */
    void reset(){
        state.reset();
        turl.reset();
        requestTime.reset();
        duration.reset();
        finalDuration.reset();
        reasonClass.reset();
        reason.reset();
        fileSize.reset();
    }
};

} // End namespace model
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_MODEL_STAGEREQ_H_
