/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: NameGeneration Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: NameGeneration.h,v 1.3 2006/08/14 08:37:50 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_NAMEGEN_NAMEGENERATION_H_
#define GLITE_DATA_TRANSFER_AGENTS_NAMEGEN_NAMEGENERATION_H_

#include <string>

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace namegen {

/**
 * NameGeneration Interface.
 * Define the interface for generation new file SURL starting from the logical 
 * name
 */
class NameGeneration{
public:
    /**
     * Destructor
     */
    virtual ~NameGeneration(){}
        
    /**
     * Generate a destination Name SURL starting from the logical name and the 
     * Se path
     * @param logical [IN] The input Logical Name. It can be either LFN or GUID
     * @param endpoint [IN] The Storage Element endpoint
     * @param se_path [IN] The path on the Storage Element
     * @param storage_class [IN] The storage class for the given file
     * @trhow LogicError, NameGenerationException in case of errors        
     * @return the generated name
     */
    virtual std::string generate(const std::string& logical,const std::string& endpoint, const std::string& se_path, const std::string& storage_class) /*throw (LogicError, NameGenerationException)*/ = 0;

protected:
    /**
     * Constructor
     */
    NameGeneration(){}
};

} // End namespace namegen
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_NAMEGEN_NAMEGENERATION_H_
