/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: NameGenerationFactory Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: NameGenerationFactory.h,v 1.2 2006/08/14 08:37:50 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_NAMEGEN_NAMEGENERATIONFACTORY_H_
#define GLITE_DATA_TRANSFER_AGENTS_NAMEGEN_NAMEGENERATIONFACTORY_H_

#include "glite/data/transfer/agent/namegen/NameGeneration.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace namegen {

/**
 * NameGenerationFactory interface
 * @interface
 */
class NameGenerationFactory {
public:

    /**
     * Create a NameGeneration instance
     * @return a new instance of a NameGeneration
     */
    virtual NameGeneration * create() /*throw ()*/; 

    /**
     * Return the configured NameGenerationFactory Instance. Please note that 
     * this method doesn't allocate the instance (it's not a singleton)
     * @return the configued NameGenerationFactory 
     * @throws LogicError in case of no NameGenerationFactory is
     * configured
     */
    static NameGenerationFactory& instance() /*throw (LogicError)*/; 
   
protected:

    /**
     * Constructor
     */ 
    NameGenerationFactory();

    /**
     * Destructor
     */ 
    virtual ~NameGenerationFactory();

private:

    /**
     * The registered Instance
     */
    static NameGenerationFactory * s_instance;
    
    /** @link dependency 
     * @label creates*/
    /*# NameGeneration lnkNameGeneration; */
};

} // End namespace namegen
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_NAMEGEN_NAMEGENERATIONFACTORY_H_
