/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: ActionScheduler Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: ActionScheduler.h,v 1.2 2006/08/14 08:37:51 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
#ifndef GLITE_DATA_TRANSFER_AGENTS_ACTIONSCHEDULER_H_
#define GLITE_DATA_TRANSFER_AGENTS_ACTIONSCHEDULER_H_

#include "glite/data/agents/extra/ActiveObject.h"
#include "glite/data/agents/dao/DAOContext.h"
#include "glite/data/agents/AgentExceptions.h"

#include <vector>

namespace log4cpp{
class Category;
}    

namespace glite    {
namespace data     {
namespace transfer {
namespace agent    {
        
/**
 * ActionScheduler Class: Executes File Transfer Agent Actions 
 * @stereotype ActiveObject
 */
class ActionScheduler : public glite::data::agents::ActiveObject {
public:
    
    /**
     * Listener for Scheduler thread Start and Stop Events
     */
    class Listener {
    public: 
        /**
         * Handle Event Start. This method would be called on the Scheduler
         * Thread when the thread is started
         */
        virtual bool onEventStart() /*throw()*/ = 0;
        /**
         * Handle Event Stop. This method would be called when the Scheduler
         * Thread when the thread is going to stop
         */
        virtual bool onEventStop() /*throw()*/ = 0;        
    };

    /**
     * Constructor
     */
    ActionScheduler(const std::string& name, glite::data::agents::dao::DAOContext& ctx, Listener * listener = 0);
    
    /**
     * Destructor
     */
    virtual ~ActionScheduler();

    //--------------------------------------------------------------------------
    // ServiceConfiguration interface
    //--------------------------------------------------------------------------
    
    /**
     * Add a new entry for the Scheduler
     */
    void add(class SchedulerEntry* entry);

    /**
     * Clear all the scheduled entries
     */
    void clear();
    
protected :
    
    /**
     * Service Main Method
     */
    virtual void svc() throw() ;

    /**
     * Handle Event Start. This method would be called on the ActiveObject thread
     * when the Object is started
     */
    virtual bool onEventStart() throw();
    /**
     * Handle Event Stop. This method would be called on the the ActiveObject thread
     * when the Object is going to stop
     */
    virtual bool onEventStop() throw();

    /**
     * Terminate the DAOContext
     */
    virtual void terminate() throw();

private:
    /**
     * Default Constructor. Not Implemented
     */
    ActionScheduler(); 

private:
    
    /**
     * SchedulerEntryList Type
     */
    typedef std::vector<class SchedulerEntry*> SchedulerEntryList;

    /**
     * The Logger
     */
    class log4cpp::Category& m_logger;

    /**
     * The event Listener
     */
    Listener * m_listener;
    
    /**
     * @label schedules
     * @link aggregation 
     * @supplierCardinality *
     */
    /*#SchedulerEntry * lnkSchedulerEntry;*/
    SchedulerEntryList  m_actions;
    
    /**
     * DAO Context
     */
    glite::data::agents::dao::DAOContext& m_ctx;
};

} // end namespace agent
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_ACTIONSCHEDULER_H_
