/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: SchedulerEntry Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: SchedulerEntry.h,v 1.2 2006/08/14 08:37:51 badino Exp $
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 *
 */
 
#ifndef GLITE_DATA_TRANSFER_AGENTS_SCHEDULERENTRY_H_
#define GLITE_DATA_TRANSFER_AGENTS_SCHEDULERENTRY_H_

#include "glite/data/agents/AgentExceptions.h"
#include "glite/data/agents/dao/DAOContext.h"
#include "glite/data/transfer/agent/action/Action.h"
#include "glite/data/transfer/agent/action/ActionFactory.h"
#include "glite/data/transfer/agent/action/ActionFactoryMethod.h"

#include <string>
#include <time.h>
#include <boost/utility.hpp>

namespace glite    {
namespace data     {
namespace transfer {
namespace agent    {    
        
/**
 * SchedulerEntry Class
 */    
class SchedulerEntry : boost::noncopyable{
public:

    /**
     * Constructor
     */
    SchedulerEntry(action::ActionFactoryMethod& f, const std::string& scope, time_t i, const std::string& params = "");

    /**
     * Destructor
     */
    ~SchedulerEntry();

    // -------------------------------------------------------------------------
    // Properties
    // -------------------------------------------------------------------------

    /**
     * Return Interval Time
     */
    time_t interval() const { return m_interval; }

    /**
     * Return Last Execution Time
     */
    time_t last() const { return m_last; }
    
    /**
     * Return the number of consecutive failures
     */
    unsigned long failures() const { return m_failures; }
    
    /**
     * Enable the Scheduler Entry
     */
    void enable();

    /**
     * Disable the Scheduler Entry
     */
    void disable(unsigned long duration);

    /**
     * Return true if the the Scheduler Entry is enabled
     */
    bool isEnabled();
    
    /**
     * Execute the related Action and update the last execution time
     */        
    void run(glite::data::agents::dao::DAOContext& ctx) /*throw (LogicError, RuntimeError)*/;
    
    /**
     * Get Action Type
     */        
    const std::string& type() const;
        
private:

    /**
     * Default Constructor. Not Implemented
     */
    SchedulerEntry();
private:
    
    /**
     * Action type
     * @link dependency
     */
    action::ActionFactoryMethod& m_actionFactory;

    /**
     * Action scope
     */
    std::string m_actionScope;

    /**
     * Action params
     */
    std::string m_actionParams;

    /**
     * Action Interval, in seconds
     */
    time_t m_interval;

    /**
     * Last Execution Time
     */
    time_t m_last;

    /**
     * Count the Consecutive Failures
     */
    unsigned long m_failures;

    /**
     * Disable Timestamp Property
     */
    time_t m_disableTimestamp;
    
    /**
     * @label executes 
     * @supplierCardinality *
     * @directed
     */
    /*# action::Action * lnkAction;*/
};

} // end namespace agent
} // end namespace transfer
} // end namespace data
} // end namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_SCHEDULERENTRY_H_
