/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data Transfer Agents: TransferException Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: TransferException.h,v 1.3 2006/12/22 16:35:10 badino Exp $ 
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 */ 
#ifndef GLITE_DATA_TRANSFER_AGENTS_TRANSFEREXCEPTION_H_
#define GLITE_DATA_TRANSFER_AGENTS_TRANSFEREXCEPTION_H_

#include "glite/data/agents/AgentExceptions.h"
#include "glite/data/transfer/agent/model/Error.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace ts      {
    
/**
 * The TransferException is thrown when an error happens contacting the
 * FileTransfer Sevrice
 */
class TransferException : public glite::data::agents::RuntimeError {
public:

    /**
     * Constructor
     * @param c [IN] the error Category
     * @param reason [IN] the reason of the error
     */
    TransferException(glite::data::transfer::agent::model::Error::Category c, 
        const char * reason):glite::data::agents::RuntimeError(reason),m_category(c){}

    /**
     * Destructor
     */
    virtual ~TransferException() throw() {}
    
    /**
     * Get Error Category Property
     */
    glite::data::transfer::agent::model::Error::Category category() const {return m_category;};
        
private:

    /**
     * Default Constructor Not Implemented
     */
    TransferException();
private:
    
    /**
     * Error Category Property
     */
    glite::data::transfer::agent::model::Error::Category m_category;
};

} // End namespace ts
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_TRANSFEREXCEPTION_H_
