/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004. 
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.  
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 *
 *  GLite Data Transfer Agents: TransferServiceFactory Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: TransferServiceFactory.h,v 1.3 2006/12/22 16:35:10 badino Exp $ 
 *  Release: $Name: glite-data-transfer-agents_R_3_0_2_2 $
 */
 
#ifndef GLITE_DATA_TRANSFER_AGENTS_TS_TRANSFERSERVICEFACTORY_H_
#define GLITE_DATA_TRANSFER_AGENTS_TS_TRANSFERSERVICEFACTORY_H_

#include "glite/data/transfer/agent/ts/TransferException.h"
#include "glite/data/transfer/agent/ts/TransferService.h"

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace ts      {

/**
 * TransferServiceFactory interface
 * @interface
 */
class TransferServiceFactory {
public:

    /**
     * Create a TransferService Proxy for the given channel
     * @param channel_name [IN] the name of the channel the TransferService is
     * responsible for
     * @return a new instance of a TransferService
     * @throws LogicError in case of error
     */
    virtual TransferService * create(const std::string& channel_name) /*throw (LogicError)*/ = 0; 

    /**
     * Return the configured TransferServiceFactory Instance. Please note that 
     * this method doesn't allocate the instance (It's not a singleton)
     * @return the configued TransferServiceFactory 
     * @throws LogicError in case of no TransferServiceFactory is
     * configured
     */
    static TransferServiceFactory& instance() /*throw (LogicError)*/; 
   
protected:

    /**
     * Constructor
     */ 
    TransferServiceFactory();

    /**
     * Destructor
     */ 
    virtual ~TransferServiceFactory();

private:

    /**
     * The registered Instance
     */
    static TransferServiceFactory * s_instance;
    
    /** @link dependency 
     * @label creates*/
    /*# TransferService lnkTransferService; */

    /** @link dependency 
     * @label throws*/
    /*# TransferException lnkTransferException; */
};

} // End namespace ts
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite

#endif //GLITE_DATA_TRANSFER_AGENTS_TS_TRANSFERSERVICEFACTORY_H_
