<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="text" indent="no"/>
<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz-</xsl:variable>
<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ_</xsl:variable>
<!-- Input Parameters -->
<xsl:param name="Prefix" select="''"/>
<xsl:param name="MappingFile" select="'fta-alias-mapping.xml'"/>
<xsl:param name="PrintUsage" select="''"/>
<!-- Mapping document -->
<xsl:variable name="mapping" select="document($MappingFile)"/>

<!-- Print Usage-->
<xsl:template name="Usage">
#
# When running the XSLT, you can provide the following parameters:
#  - Prefix ${PREFIX_VALUE}: add a prefix to all the variables
#  - PrintUsage ${ANY_STRING}: Print this error message
#  - MappingFile ${ALIAS_MAPPING_FILE}: use a file that provides a mapping 
#    between the FTA component name and an user friendly alias. 
#    This file should be in the format:
# <![CDATA[
#     <mapping>
#       <component name="${component_name}">${alias_value}</component>
#       <component name="${component_name}">${alias_value}</component>
#       <!-- ... -->
#     </mapping>
#    ]]>
#    Please note that the location of the mapping file is relative to the location of the XSLT file
#    The Default for this parameter is 'fta-alias-mapping.xml'
#
</xsl:template>

<!-- Get Prefix-->
<xsl:template name="GetPrefix">
 <xsl:param name="node"/>
 <xsl:variable name="alias_val">
  <xsl:choose>
   <xsl:when test="$node/@alias"><xsl:value-of select="$node/@alias"/></xsl:when>
   <xsl:otherwise><xsl:value-of select="$mapping/mapping/component[@name=$node/@name]"/></xsl:otherwise>
  </xsl:choose>
 </xsl:variable>
 <xsl:if test="string($Prefix)"><xsl:value-of select="translate($Prefix,$lcletters,$ucletters)"/>_</xsl:if>
 <xsl:if test="string($alias_val)"> <xsl:value-of select="translate($alias_val,$lcletters,$ucletters)"/>_</xsl:if>
</xsl:template>

<!-- Process param -->
<xsl:template name="ProcessParam">
<xsl:param name="param_prefix"/>
<xsl:param name="comp_name"/>
<xsl:if test="$param_prefix">
<xsl:value-of select="$param_prefix"/>
</xsl:if>
<xsl:value-of select="translate(@name,$lcletters,$ucletters)"/>=&quot;<xsl:value-of select="$comp_name"/>.<xsl:value-of select="@name"/>&quot;
</xsl:template>
<!-- Add Log Params -->
<xsl:template name="AddLogParams">
<xsl:if test="string($Prefix)"><xsl:value-of select="translate($Prefix,$lcletters,$ucletters)"/>_</xsl:if>LOG_FILENAME=&quot;log.fileName&quot;
<xsl:if test="string($Prefix)"><xsl:value-of select="translate($Prefix,$lcletters,$ucletters)"/>_</xsl:if>LOG_PRIORITY=&quot;log.Priority&quot;
</xsl:template>
<!-- Add Hardcoded Params -->
<xsl:template name="AddHardCodedParams">
<xsl:if test="string($Prefix)"><xsl:value-of select="translate($Prefix,$lcletters,$ucletters)"/>_</xsl:if>INSTANCENAME=&quot;Name&quot;
</xsl:template>

<!-- Process each component -->
<xsl:template match="component[@name]">
<xsl:variable name="comp_name" select="@name"/>
<!-- Get the prefix to be used for the component -->
<xsl:variable name="param_prefix">
  <xsl:call-template name="GetPrefix">
    <xsl:with-param name="node" select="."/>
 </xsl:call-template>
 </xsl:variable>
<!-- For each initialization parameters -->
<xsl:for-each select="config-template/init/param[@name]">
<xsl:call-template name="ProcessParam">
    <xsl:with-param name="param_prefix" select="$param_prefix"/>
    <xsl:with-param name="comp_name" select="$comp_name"/>
 </xsl:call-template>
</xsl:for-each>
<!-- For each configuration parameters -->
<xsl:for-each select="config-template/config/param[@name]">
<xsl:call-template name="ProcessParam">
    <xsl:with-param name="param_prefix" select="$param_prefix"/>
    <xsl:with-param name="comp_name" select="$comp_name"/>
 </xsl:call-template>
</xsl:for-each>
</xsl:template> 

<!-- Start the macthing -->
<xsl:template match="/service">
#
# Auto-generated mapping file for FTA YAIM configuration script. 
#
<xsl:if test="string($PrintUsage)">
    <xsl:call-template name="Usage"/>
</xsl:if>
<xsl:apply-templates/>
<xsl:call-template name="AddLogParams"/>
<xsl:call-template name="AddHardCodedParams"/>
</xsl:template>
</xsl:stylesheet>
